@@ -2,18 +2,19 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2
-# remove :certainty
-##
-Plugin.define "MD5" do
-author "Andrew Horton"
+Plugin.define do
+name "MD5"
+authors [
+  "Andrew Horton",
+  # v0.2 # remove :certainty. 
+]
 version "0.2"
 description "MD5 sum of html body. Useful to find matching pages"
 
 # Passive #
-def passive
+passive do
 	m=[]
 
 	# MD5 hash of HTML source # :string=>Digest::MD5.hexdigest(@body)	
