@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Biscom-Delivery-Server" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-11-20
+Plugin.define do
+name "Biscom-Delivery-Server"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-11-20
+]
 version "0.1"
 description "Biscom Delivery Server - Secure File Transfer (SFT) software"
 website "http://www.biscomdeliveryserver.com/"
