@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2011-03-02 #
-# Updated version detection
-##
-Plugin.define "X7-Chat" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-06-13 
+Plugin.define do
+name "X7-Chat"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-06-13 
+  # v0.2 # 2011-03-02 # Updated version detection. 
+]
 version "0.2"
 description "X7 Chat is a free script that can be modified and redistributed in any way that you want as long as the X7 Chat copyright logo remains in place."
 website "http://x7chat.com/"
